@@ -362,6 +362,10 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
                 client_cert_source_for_mtls=client_cert_source_func,
                 quota_project_id=client_options.quota_project_id,
                 client_info=client_info,
+                always_use_jwt_access=(
+                    Transport == type(self).get_transport_class("grpc")
+                    or Transport == type(self).get_transport_class("grpc_asyncio")
+                ),
             )
 
     def create_dashboard(
@@ -374,10 +378,11 @@ class DashboardsServiceClient(metaclass=DashboardsServiceClientMeta):
     ) -> dashboard.Dashboard:
         r"""Creates a new custom dashboard. For examples on how you can use
         this API to create dashboards, see `Managing dashboards by
-        API </monitoring/dashboards/api-dashboard>`__. This method
-        requires the ``monitoring.dashboards.create`` permission on the
-        specified project. For more information about permissions, see
-        `Cloud Identity and Access Management </iam>`__.
+        API <https://cloud.google.com/monitoring/dashboards/api-dashboard>`__.
+        This method requires the ``monitoring.dashboards.create``
+        permission on the specified project. For more information about
+        permissions, see `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Args:
             request (google.cloud.monitoring_dashboard_v1.types.CreateDashboardRequest):
