@@ -236,10 +236,11 @@ class DashboardsServiceGrpcTransport(DashboardsServiceTransport):
 
         Creates a new custom dashboard. For examples on how you can use
         this API to create dashboards, see `Managing dashboards by
-        API </monitoring/dashboards/api-dashboard>`__. This method
-        requires the ``monitoring.dashboards.create`` permission on the
-        specified project. For more information about permissions, see
-        `Cloud Identity and Access Management </iam>`__.
+        API <https://cloud.google.com/monitoring/dashboards/api-dashboard>`__.
+        This method requires the ``monitoring.dashboards.create``
+        permission on the specified project. For more information about
+        permissions, see `Cloud Identity and Access
+        Management <https://cloud.google.com/iam>`__.
 
         Returns:
             Callable[[~.CreateDashboardRequest],
