@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
 
@@ -25,11 +23,10 @@ __protobuf__ = proto.module(
 
 class Text(proto.Message):
     r"""A widget that displays textual content.
-
     Attributes:
         content (str):
             The text content to be displayed.
-        format_ (~.text.Text.Format):
+        format_ (google.cloud.monitoring_dashboard_v1.types.Text.Format):
             How the text content is formatted.
     """
 
@@ -39,8 +36,7 @@ class Text(proto.Message):
         MARKDOWN = 1
         RAW = 2
 
-    content = proto.Field(proto.STRING, number=1)
-
+    content = proto.Field(proto.STRING, number=1,)
     format_ = proto.Field(proto.ENUM, number=2, enum=Format,)
 
 
